class AfifNode:

    def __init__(self, value):
        self.data_value = value
        self.next = None

    def description(self):
        print(f"value : {self.data_value}, next : {self.next}")

    def next_node(self):
        return self.next



from setuptools import setup

setup(
    name='afif',         # How you named your package folder (MyLib)
    packages=['src'],   # Chose the same as "name"
    version='0.1.1',      # Start with a small number and increase it with every change you make
    license='MIT',
    description='this package is create to remembering me about create, install, use in local, and publishing in pipy',
    author='Muhammad Afif Nur Azizi',
    author_email='afifnurazizi@gmail.com',
)
